@@ -570,9 +570,7 @@ func TestRefresher(t *testing.T) {
 			Type: Checksum,
 		})
 
-		for _, item := range artifacts.List() {
-			require.NoError(t, item.Refresh())
-		}
+		require.NoError(t, artifacts.Refresh())
 
 		bts, err := os.ReadFile(path)
 		require.NoError(t, err)
@@ -635,7 +633,7 @@ func TestVisit(t *testing.T) {
 	})
 
 	t.Run("nok", func(t *testing.T) {
-		require.EqualError(t, artifacts.Visit(func(a *Artifact) error {
+		require.EqualError(t, artifacts.Visit(func(_ *Artifact) error {
 			return fmt.Errorf("fake err")
 		}), `fake err`)
 	})
@@ -936,7 +934,7 @@ func TestArtifactStringer(t *testing.T) {
 }
 
 func TestArtifactTypeStringer(t *testing.T) {
-	for i := 1; i <= 29; i++ {
+	for i := 1; i <= 30; i++ {
 		t.Run(fmt.Sprintf("type-%d-%s", i, Type(i).String()), func(t *testing.T) {
 			require.NotEqual(t, "unknown", Type(i).String())
 		})
