@@ -52,7 +52,9 @@ func (r Repo) String() string {
 // Client interface.
 type Client interface {
 	CloseMilestone(ctx *context.Context, repo Repo, title string) (err error)
+	// Creates a release. It's marked as draft if possible (should call PublishRelease to finish publishing).
 	CreateRelease(ctx *context.Context, body string) (releaseID string, err error)
+	PublishRelease(ctx *context.Context, releaseID string) (err error)
 	Upload(ctx *context.Context, releaseID string, artifact *artifact.Artifact, file *os.File) (err error)
 	Changelog(ctx *context.Context, repo Repo, prev, current string) (string, error)
 	ReleaseURLTemplater
@@ -88,6 +90,11 @@ type ReleaseNotesGenerator interface {
 	GenerateReleaseNotes(ctx *context.Context, repo Repo, prev, current string) (string, error)
 }
 
+// ForkSyncer can sync forks.
+type ForkSyncer interface {
+	SyncFork(ctx *context.Context, head, base Repo) error
+}
+
 // PullRequestOpener can open pull requests.
 type PullRequestOpener interface {
 	OpenPullRequest(ctx *context.Context, base, head Repo, title string, draft bool) error
