@@ -14,7 +14,7 @@ import (
 
 	"github.com/caarlos0/log"
 	"github.com/charmbracelet/x/exp/ordered"
-	"github.com/google/go-github/v57/github"
+	"github.com/google/go-github/v61/github"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -28,6 +28,7 @@ var (
 	_ Client                = &githubClient{}
 	_ ReleaseNotesGenerator = &githubClient{}
 	_ PullRequestOpener     = &githubClient{}
+	_ ForkSyncer            = &githubClient{}
 )
 
 type githubClient struct {
@@ -68,7 +69,7 @@ func newGitHub(ctx *context.Context, token string) (*githubClient, error) {
 }
 
 func (c *githubClient) checkRateLimit(ctx *context.Context) {
-	limits, _, err := c.client.RateLimits(ctx)
+	limits, _, err := c.client.RateLimit.Get(ctx)
 	if err != nil {
 		log.Warn("could not check rate limits, hoping for the best...")
 		return
@@ -217,6 +218,7 @@ func (c *githubClient) OpenPullRequest(
 	if len(tpl) > 0 {
 		log.Info("got a pr template")
 	}
+
 	log := log.
 		WithField("base", headString(base, Repo{})).
 		WithField("head", headString(base, head)).
@@ -245,6 +247,31 @@ func (c *githubClient) OpenPullRequest(
 	return nil
 }
 
+func (c *githubClient) SyncFork(ctx *context.Context, head, base Repo) error {
+	branch := base.Branch
+	if branch == "" {
+		def, err := c.getDefaultBranch(ctx, base)
+		if err != nil {
+			return err
+		}
+		branch = def
+	}
+	res, _, err := c.client.Repositories.MergeUpstream(
+		ctx,
+		head.Owner,
+		head.Name,
+		&github.RepoMergeUpstreamRequest{
+			Branch: github.String(branch),
+		},
+	)
+	if res != nil {
+		log.WithField("merge_type", res.GetMergeType()).
+			WithField("base_branch", res.GetBaseBranch()).
+			Info(res.GetMessage())
+	}
+	return err
+}
+
 func (c *githubClient) CreateFile(
 	ctx *context.Context,
 	commitAuthor config.CommitAuthor,
@@ -354,10 +381,12 @@ func (c *githubClient) CreateRelease(ctx *context.Context, body string) (string,
 	body = truncateReleaseBody(body)
 
 	data := &github.RepositoryRelease{
-		Name:       github.String(title),
-		TagName:    github.String(ctx.Git.CurrentTag),
-		Body:       github.String(body),
-		Draft:      github.Bool(ctx.Config.Release.Draft),
+		Name:    github.String(title),
+		TagName: github.String(ctx.Git.CurrentTag),
+		Body:    github.String(body),
+		// Always start with a draft release while uploading artifacts.
+		// PublishRelease will undraft it.
+		Draft:      github.Bool(true),
 		Prerelease: github.Bool(ctx.PreRelease),
 		MakeLatest: github.String("true"),
 	}
@@ -388,6 +417,19 @@ func (c *githubClient) CreateRelease(ctx *context.Context, body string) (string,
 	return strconv.FormatInt(release.GetID(), 10), nil
 }
 
+func (c *githubClient) PublishRelease(ctx *context.Context, releaseID string) (err error) {
+	releaseIDInt, err := strconv.ParseInt(releaseID, 10, 64)
+	if err != nil {
+		return fmt.Errorf("non-numeric release ID %q: %w", releaseID, err)
+	}
+	if _, err := c.updateRelease(ctx, releaseIDInt, &github.RepositoryRelease{
+		Draft: github.Bool(ctx.Config.Release.Draft),
+	}); err != nil {
+		return fmt.Errorf("could not update existing release: %w", err)
+	}
+	return nil
+}
+
 func (c *githubClient) createOrUpdateRelease(ctx *context.Context, data *github.RepositoryRelease, body string) (*github.RepositoryRelease, error) {
 	c.checkRateLimit(ctx)
 	release, _, err := c.client.Repositories.GetReleaseByTag(
@@ -448,6 +490,50 @@ func (c *githubClient) ReleaseURLTemplate(ctx *context.Context) (string, error)
 	), nil
 }
 
+func (c *githubClient) deleteReleaseArtifact(ctx *context.Context, releaseID int64, name string, page int) error {
+	c.checkRateLimit(ctx)
+	log.WithField("name", name).Info("delete pre-existing asset from the release")
+	assets, resp, err := c.client.Repositories.ListReleaseAssets(
+		ctx,
+		ctx.Config.Release.GitHub.Owner,
+		ctx.Config.Release.GitHub.Name,
+		releaseID,
+		&github.ListOptions{
+			PerPage: 100,
+			Page:    page,
+		},
+	)
+	if err != nil {
+		githubErrLogger(resp, err).
+			WithField("release-id", releaseID).
+			Warn("could not list release assets")
+		return err
+	}
+	for _, asset := range assets {
+		if asset.GetName() != name {
+			continue
+		}
+		resp, err := c.client.Repositories.DeleteReleaseAsset(
+			ctx,
+			ctx.Config.Release.GitHub.Owner,
+			ctx.Config.Release.GitHub.Name,
+			asset.GetID(),
+		)
+		if err != nil {
+			githubErrLogger(resp, err).
+				WithField("release-id", releaseID).
+				WithField("id", asset.GetID()).
+				WithField("name", name).
+				Warn("could not delete asset")
+		}
+		return err
+	}
+	if next := resp.NextPage; next > 0 {
+		return c.deleteReleaseArtifact(ctx, releaseID, name, next)
+	}
+	return nil
+}
+
 func (c *githubClient) Upload(
 	ctx *context.Context,
 	releaseID string,
@@ -470,20 +556,25 @@ func (c *githubClient) Upload(
 		file,
 	)
 	if err != nil {
-		requestID := ""
-		if resp != nil {
-			requestID = resp.Header.Get("X-GitHub-Request-Id")
-		}
-		log.WithField("name", artifact.Name).
+		githubErrLogger(resp, err).
+			WithField("name", artifact.Name).
 			WithField("release-id", releaseID).
-			WithField("request-id", requestID).
 			Warn("upload failed")
 	}
 	if err == nil {
 		return nil
 	}
+	// this status means the asset already exists
 	if resp != nil && resp.StatusCode == http.StatusUnprocessableEntity {
-		return err
+		if !ctx.Config.Release.ReplaceExistingArtifacts {
+			return err
+		}
+		// if the user allowed to delete assets, we delete it, and return a
+		// retriable error.
+		if err := c.deleteReleaseArtifact(ctx, githubReleaseID, artifact.Name, 1); err != nil {
+			return err
+		}
+		return RetriableError{err}
 	}
 	return RetriableError{err}
 }
@@ -591,3 +682,11 @@ func (c *githubClient) deleteExistingDraftRelease(ctx *context.Context, name str
 		opt.Page = resp.NextPage
 	}
 }
+
+func githubErrLogger(resp *github.Response, err error) *log.Entry {
+	requestID := ""
+	if resp != nil {
+		requestID = resp.Header.Get("X-GitHub-Request-Id")
+	}
+	return log.WithField("request-id", requestID).WithError(err)
+}
