@@ -8,24 +8,19 @@ import (
 	"text/template"
 
 	"github.com/caarlos0/log"
-	"github.com/charmbracelet/lipgloss"
+	"github.com/goreleaser/goreleaser/internal/logext"
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
 
 const baseURL = "https://goreleaser.com/deprecations#"
 
-var warnStyle = lipgloss.NewStyle().Foreground(lipgloss.Color("11")).Bold(true)
-
 // Notice warns the user about the deprecation of the given property.
 func Notice(ctx *context.Context, property string) {
-	NoticeCustom(ctx, property, "`{{ .Property }}` should not be used anymore, check {{ .URL }} for more info")
+	NoticeCustom(ctx, property, "{{ .Property }} should not be used anymore, check {{ .URL }} for more info")
 }
 
 // NoticeCustom warns the user about the deprecation of the given property.
 func NoticeCustom(ctx *context.Context, property, tmpl string) {
-	log.IncreasePadding()
-	defer log.DecreasePadding()
-
 	// replaces . and _ with -
 	url := baseURL + strings.NewReplacer(
 		".", "",
@@ -37,14 +32,14 @@ func NoticeCustom(ctx *context.Context, property, tmpl string) {
 	if err := template.
 		Must(template.New("deprecation").Parse("DEPRECATED: "+tmpl)).
 		Execute(&out, templateData{
-			URL:      url,
-			Property: property,
+			URL:      logext.URL(url),
+			Property: logext.Keyword(property),
 		}); err != nil {
 		panic(err) // this should never happen
 	}
 
 	ctx.Deprecated = true
-	log.Warn(warnStyle.Render(out.String()))
+	log.Warn(logext.Warning(out.String()))
 }
 
 type templateData struct {
