@@ -59,6 +59,10 @@ func (Pipe) Default(ctx *context.Context) error {
 		if archive.ID == "" {
 			archive.ID = "default"
 		}
+		if archive.StripParentBinaryFolder {
+			archive.StripBinaryDirectory = true
+			deprecate.Notice(ctx, "archives.strip_parent_binary_folder")
+		}
 		if archive.RLCP != "" && archive.Format != "binary" && len(archive.Files) > 0 {
 			deprecate.Notice(ctx, "archives.rlcp")
 		}
@@ -112,15 +116,20 @@ func (Pipe) Run(ctx *context.Context) error {
 		for group, artifacts := range artifacts {
 			log.Debugf("group %s has %d binaries", group, len(artifacts))
 			artifacts := artifacts
-			if packageFormat(archive, artifacts[0].Goos) == "binary" {
+			format := packageFormat(archive, artifacts[0].Goos)
+			switch format {
+			case "none":
+				// do nothing
+				log.WithField("goos", artifacts[0].Goos).Info("ignored due to format override to 'none'")
+			case "binary":
 				g.Go(func() error {
 					return skip(ctx, archive, artifacts)
 				})
-				continue
+			default:
+				g.Go(func() error {
+					return create(ctx, archive, artifacts, format)
+				})
 			}
-			g.Go(func() error {
-				return create(ctx, archive, artifacts)
-			})
 		}
 	}
 	return g.Wait()
@@ -138,15 +147,10 @@ func checkArtifacts(artifacts map[string][]*artifact.Artifact) error {
 }
 
 func createMeta(ctx *context.Context, arch config.Archive) error {
-	return doCreate(ctx, arch, nil, arch.Format)
+	return create(ctx, arch, nil, arch.Format)
 }
 
-func create(ctx *context.Context, arch config.Archive, binaries []*artifact.Artifact) error {
-	format := packageFormat(arch, binaries[0].Goos)
-	return doCreate(ctx, arch, binaries, format)
-}
-
-func doCreate(ctx *context.Context, arch config.Archive, binaries []*artifact.Artifact, format string) error {
+func create(ctx *context.Context, arch config.Archive, binaries []*artifact.Artifact, format string) error {
 	template := tmpl.New(ctx)
 	if len(binaries) > 0 {
 		template = template.WithArtifact(binaries[0])
@@ -202,7 +206,7 @@ func doCreate(ctx *context.Context, arch config.Archive, binaries []*artifact.Ar
 	bins := []string{}
 	for _, binary := range binaries {
 		dst := binary.Name
-		if arch.StripParentBinaryFolder {
+		if arch.StripBinaryDirectory {
 			dst = filepath.Base(dst)
 		}
 		if err := a.Add(config.File{
