@@ -1,14 +1,15 @@
 package discord
 
 import (
+	"bytes"
+	"encoding/json"
 	"fmt"
+	"net/http"
+	"net/url"
 	"strconv"
 
 	"github.com/caarlos0/env/v9"
 	"github.com/caarlos0/log"
-	"github.com/disgoorg/disgo/discord"
-	"github.com/disgoorg/disgo/webhook"
-	"github.com/disgoorg/snowflake/v2"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
@@ -59,19 +60,21 @@ func (p Pipe) Announce(ctx *context.Context) error {
 
 	log.Infof("posting: '%s'", msg)
 
-	webhookID, err := snowflake.Parse(cfg.WebhookID)
-	if err != nil {
-		return fmt.Errorf("discord: %w", err)
-	}
-
 	color, err := strconv.Atoi(ctx.Config.Announce.Discord.Color)
 	if err != nil {
 		return fmt.Errorf("discord: %w", err)
 	}
-	if _, err = webhook.New(webhookID, cfg.WebhookToken).CreateMessage(discord.WebhookMessageCreate{
-		Embeds: []discord.Embed{
+
+	u, err := url.Parse("https://discord.com/api")
+	if err != nil {
+		return fmt.Errorf("discord: %w", err)
+	}
+	u = u.JoinPath("webhooks", cfg.WebhookID, cfg.WebhookToken)
+
+	bts, err := json.Marshal(WebhookMessageCreate{
+		Embeds: []Embed{
 			{
-				Author: &discord.EmbedAuthor{
+				Author: &EmbedAuthor{
 					Name:    ctx.Config.Announce.Discord.Author,
 					IconURL: ctx.Config.Announce.Discord.IconURL,
 				},
@@ -79,8 +82,34 @@ func (p Pipe) Announce(ctx *context.Context) error {
 				Color:       color,
 			},
 		},
-	}); err != nil {
+	})
+	if err != nil {
 		return fmt.Errorf("discord: %w", err)
 	}
+
+	resp, err := http.Post(u.String(), "application/json", bytes.NewReader(bts))
+	if err != nil {
+		return fmt.Errorf("discord: %w", err)
+	}
+
+	if resp.StatusCode != 204 && resp.StatusCode != 200 {
+		return fmt.Errorf("discord: %s", resp.Status)
+	}
+
 	return nil
 }
+
+type WebhookMessageCreate struct {
+	Embeds []Embed `json:"embeds,omitempty"`
+}
+
+type Embed struct {
+	Description string       `json:"description,omitempty"`
+	Color       int          `json:"color,omitempty"`
+	Author      *EmbedAuthor `json:"author,omitempty"`
+}
+
+type EmbedAuthor struct {
+	Name    string `json:"name,omitempty"`
+	IconURL string `json:"icon_url,omitempty"`
+}
