@@ -32,6 +32,7 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 	tarfile := createTmpFile(t, folder, "bin.tar.gz")
 	srcfile := createTmpFile(t, folder, "source.tar.gz")
 	debfile := createTmpFile(t, folder, "bin.deb")
+	metafile := createTmpFile(t, folder, "metadata.json")
 	checksumfile := createTmpFile(t, folder, "checksum")
 	checksumsigfile := createTmpFile(t, folder, "checksum.sig")
 	checksumpemfile := createTmpFile(t, folder, "checksum.pem")
@@ -45,6 +46,7 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 				Owner: "test",
 				Name:  "test",
 			},
+			IncludeMeta: true,
 		},
 	}
 	ctx := testctx.NewWithCfg(config, testctx.WithCurrentTag("v1.0.0"))
@@ -94,7 +96,16 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 		Name: "checksum",
 		Path: checksumfile,
 		Extra: map[string]interface{}{
-			artifact.ExtraID: "bar",
+			artifact.ExtraID: "doesnt-matter",
+		},
+	})
+
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Type: artifact.Metadata,
+		Name: "metadata.json",
+		Path: metafile,
+		Extra: map[string]interface{}{
+			artifact.ExtraID: "doesnt-matter",
 		},
 	})
 	ctx.Artifacts.Add(&artifact.Artifact{
@@ -117,11 +128,13 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 	require.NoError(t, doPublish(ctx, client))
 	require.True(t, client.CreatedRelease)
 	require.True(t, client.UploadedFile)
+	require.True(t, client.ReleasePublished)
 	require.Contains(t, client.UploadedFileNames, "source.tar.gz")
 	require.Contains(t, client.UploadedFileNames, "bin.deb")
 	require.Contains(t, client.UploadedFileNames, "bin.tar.gz")
 	require.Contains(t, client.UploadedFileNames, "filtered.deb")
 	require.Contains(t, client.UploadedFileNames, "filtered.tar.gz")
+	require.Contains(t, client.UploadedFileNames, "metadata.json")
 	require.Contains(t, client.UploadedFileNames, "checksum")
 	require.Contains(t, client.UploadedFileNames, "checksum.pem")
 	require.Contains(t, client.UploadedFileNames, "checksum.sig")
@@ -192,6 +205,7 @@ func TestRunPipeWithIDsThenFilters(t *testing.T) {
 	require.NoError(t, doPublish(ctx, client))
 	require.True(t, client.CreatedRelease)
 	require.True(t, client.UploadedFile)
+	require.True(t, client.ReleasePublished)
 	require.Contains(t, client.UploadedFileNames, "bin.deb")
 	require.Contains(t, client.UploadedFileNames, "bin.tar.gz")
 	require.Contains(t, client.UploadedFileNames, "f1")
@@ -215,6 +229,7 @@ func TestRunPipeReleaseCreationFailed(t *testing.T) {
 	require.Error(t, doPublish(ctx, client))
 	require.False(t, client.CreatedRelease)
 	require.False(t, client.UploadedFile)
+	require.False(t, client.ReleasePublished)
 }
 
 func TestRunPipeWithFileThatDontExist(t *testing.T) {
@@ -262,6 +277,7 @@ func TestRunPipeUploadFailure(t *testing.T) {
 	require.EqualError(t, doPublish(ctx, client), "failed to upload bin.tar.gz after 1 tries: upload failed")
 	require.True(t, client.CreatedRelease)
 	require.False(t, client.UploadedFile)
+	require.False(t, client.ReleasePublished)
 }
 
 func TestRunPipeExtraFileNotFound(t *testing.T) {
@@ -330,6 +346,7 @@ func TestRunPipeUploadRetry(t *testing.T) {
 	require.NoError(t, doPublish(ctx, client))
 	require.True(t, client.CreatedRelease)
 	require.True(t, client.UploadedFile)
+	require.True(t, client.ReleasePublished)
 }
 
 func TestDefault(t *testing.T) {
